# Generated by Django 3.0.4 on 2020-03-19 11:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0004_auto_20200318_1806'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='status',
            field=models.CharField(max_length=3, verbose_name='Status'),
        ),
    ]
