from django.conf import settings

VERSION = '1.1.7'

REST_FILE_MANAGER = getattr(settings, 'REST_FILE_MANAGER', {})
UPLOADS_DIR = REST_FILE_MANAGER.get('UPLOADS_DIR', 'files/')
UPLOAD = 'UPL'
CHOICES = ((UPLOAD, 'Upload'),)
STATUS_CHOICES = REST_FILE_MANAGER.get('STATUS_CHOICES', CHOICES)
DEFAULT_CHOICE = REST_FILE_MANAGER.get('DEFAULT_CHOICE', UPLOAD)
DEFAULT_SHAREABLE = REST_FILE_MANAGER.get('DEFAULT_SHAREABLE', True)
