# Generated by Django 3.0.3 on 2020-03-11 09:22

from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0002_auto_20200302_0947'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='status',
            field=models.CharField(choices=[('PNP', 'Pending'), ('DIG', 'Doing'), ('UPL', 'Upload'), ('ERR', 'Error')], default='UPL', max_length=3, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(null=True, storage=djangorestfilemanager.models.RestFileManagerStorage(location='media'), upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
    ]
